from setuptools import setup

setup(
    name="iuShiWoDe",     #项目名
    version = "2.0",        #版本
    py_modules=["fc_xd_bigdata"],   #生成模块
    author="李龙辉大帅b",        #作者
    author_email="dh15139589060@163.com",   #邮箱
    description="项目信息"              #项目信息

)